<?php

namespace QUI\ProtectPlus;

use QUI;
use QUI\Interfaces\Users\User;
use QUI\Security\Encryption;
use QUI\Users\Address;

class Events
{
    /**
     * @var array|string[]
     */
    protected static array $userFields = [
        'firstname',
        'lastname',
        'company',
        'street_no',
        'zip',
        'city',
        'country',
        'custom_data',
        'title'
    ];

    /**
     * @param Address $Address
     * @param array<mixed> $data
     * @return void
     */
    public static function onUserAddressInitData(Address $Address, array &$data = []): void
    {
        if (!isset($data['encrypted']) || $data['encrypted'] === 0) {
            return;
        }

        foreach (self::$userFields as $userField) {
            if (isset($data[$userField])) {
                try {
                    $data[$userField] = Encryption::decrypt($data[$userField]);
                } catch (QUI\Exception) {
                }
            }
        }
    }

    /**
     * @param Address $Address
     * @param User $User
     * @param array<mixed> $dbData
     * @return void
     */
    public static function onUserAddressSaveBefore(Address $Address, User $User, array &$dbData = []): void
    {
        foreach (self::$userFields as $userField) {
            if (isset($dbData[$userField])) {
                try {
                    $dbData[$userField] = Encryption::encrypt($dbData[$userField]);
                } catch (QUI\Exception) {
                }
            }
        }

        $dbData['encrypted'] = 1;
    }
}
